@@ -9,7 +9,7 @@ import typing
 import streamlit as st
 
 from i2 import Sig
-from streamlitfront.session_state import _get_state, _SessionState
+from streamlitfront.session_state import get_state, _SessionState
 from streamlitfront.util import func_name, build_element_factory
 
 # --------------------- types/protocols/interfaces --------------------------------------
@@ -185,6 +185,9 @@ def get_func_args_specs(
             if dflt is not None:
                 # TODO: type-to-element conditions must be in configs
                 if isinstance(dflt, (list, tuple, set)):
+                    # TODO: This case seems false (maybe? don't want multiple choice
+                    #  when default is a list)
+                    # TODO: When we have list defaults, error occurs
                     factory_kwargs["options"] = dflt
                 else:
                     factory_kwargs["value"] = dflt
@@ -207,7 +210,7 @@ class BasePageFunc:
 
     def __call__(self, state):
         self.prepare_view(state)
-        st.write(Sig(self.func))
+        st.write(self.sig)  # Was Sig(self.func)
 
 
 class SimplePageFunc(BasePageFunc):
@@ -267,7 +270,12 @@ def _get_view_key(
 
 
 def pages_app(funcs, configs):
-    state = _get_state(hash_funcs=dflt_hash_funcs)  # TODO: get from configs
+    # Page setup
+
+    # Note: set_page_config at top: needs to be the first call after importing streamlit
+    st.set_page_config(layout="wide")
+
+    state = get_state(hash_funcs=dflt_hash_funcs)  # TODO: get from configs
 
     # # Experimentation -- to be reviewed if kept #############
     # if 'page_state' not in state:
@@ -276,10 +284,11 @@ def pages_app(funcs, configs):
     #         state['page_state'][func] = {}
     # full page layout style
     # st.set_page_config(**configs.get('page_config', {}))
-    # configs don't work here because the layout call has to be the first call after importing streamlit
+    # configs don't work here because the layout call has to be the first call after
+    # importing streamlit
 
-    # Page setup
-    st.set_page_config(layout="wide")
+    # # Page setup
+    # st.set_page_config(layout="wide")
 
     # Make page objects
     views = get_pages_specs(funcs, **configs)
