@@ -269,3 +269,49 @@ class StatePageFunc(BasePageFunc):
                 "New value stored in state for this function is:",
                 state[self.view_title],
             )
+
+
+from i2 import name_of_obj
+from front.py2pydantic import func_to_pyd_input_model_cls, pydantic_model_from_type
+import streamlit as st
+import streamlit_pydantic as sp  # pip install streamlit-pydantic
+
+
+class SimplePageFuncPydanticWrite(BasePageFunc):
+    def __call__(self, state):
+        self.prepare_view(state)
+        mymodel = func_to_pyd_input_model_cls(self.func)
+        name = name_of_obj(self.func)
+        data = sp.pydantic_form(key=f"my_form_{name}", model=mymodel)
+        # data = sp.pydantic_input(key=f"my_form_{name}", model=mymodel)
+
+        if data:
+            # print(f"--------st.write(self.func(**dict(data)))")
+            # print(f"{Sig(self.func)}")
+            # print(f"{dict(data)}")
+            st.write(self.func(**dict(data)))
+
+
+class SimplePageFuncPydanticWithOutput(BasePageFunc):
+    def __call__(self, state):
+        self.prepare_view(state)
+        mymodel = func_to_pyd_input_model_cls(self.func)
+        mytype = self.func.__annotations__["return"]
+        output_model = pydantic_model_from_type(mytype)
+
+        name = (
+            self.func.__name__
+        )  # check in sig, dag, lined a better way, i2, may be displayed name: name_of_obj
+
+        data = sp.pydantic_input(key=f"my_form_{name}", model=mymodel)
+
+        if data:
+            func_result = self.func(**data)
+
+            instance = output_model(result=func_result)
+
+            st.write(instance)
+            sp.pydantic_output(instance)
+
+
+# DFLT_CONFIGS = {"page_factory": SimplePageFuncPydanticWrite}
