@@ -3,6 +3,12 @@ from functools import partial
 from typing import TypeVar, Iterable, Dict
 from i2.signatures import Sig, name_of_obj, Command as _Command
 
+import streamlit.bootstrap
+
+run_streamlit = partial(
+    streamlit.bootstrap.run, command_line="", args=[], flag_options={}
+)
+
 
 # TODO: Consider using functools.partial (or subclass thereof) instead of Command
 class Command(_Command):
